package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.FoodIngredients;
import com.yunzhi.inte.entity.Package;
import com.yunzhi.inte.entity.StoreType;
import com.yunzhi.inte.service.FoodIngredientsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Dishes;
import com.yunzhi.inte.service.DishesService;

/**
 * 菜肴表;(dishes)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "菜肴表对象功能接口")
@RestController
@RequestMapping("/")
public class DishesController extends BaseController {

    @Autowired
    private DishesService dishesService;

    @Autowired
    private FoodIngredientsService foodIngredientsService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/dishes/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        Dishes dishes = dishesService.getById(id);

        // 获取详情列表
        List<Integer> list = foodIngredientsService.getItemListByDish(id);
        dishes.setIngredientsIdList(list);

        return ResponseBean.success(dishes);
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/dishes")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("名称") @RequestParam(value ="name", required = false) String name) throws Exception {

        IPage<Dishes> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<Dishes> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", name);
        queryWrapper.eq("status", 1);
        queryWrapper.orderByDesc("id");
        IPage<Dishes> result = dishesService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param dishes 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/dishes")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Dishes dishes) throws Exception {
        Dishes origin = dishesService.getExistBy("name", dishes.getName(), false, true);

        List<Integer> ingredientsList = dishes.getIngredientsIdList();
        Integer foodNum = null == ingredientsList ? 0 : ingredientsList.size();
        dishes.setFoodNum(foodNum);

        Integer dishId = dishes.getId();
        if (dishId == null) {
            if (null != origin) {
                return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }

            dishes.setStatus(1);
            dishesService.save(dishes);
            dishId = dishes.getId();
        } else {
            if (null != origin && !dishId.equals(origin.getId())) {
                return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }

            dishesService.updateById(dishes);
        }

        foodIngredientsService.addOrUpdate(dishId, ingredientsList);

        return ResponseBean.success(dishes);
    }

    /**
     * 更新数据
     *
     * @param dishes 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/dishes/{id}")
    public ResponseBean edit(@ApiParam("对象ID") @PathVariable Integer id,
                             @ApiParam("对象实体") @RequestBody Dishes dishes) throws Exception {
        Dishes origin = dishesService.getExistBy("name", dishes.getName(), false, true);
        if (null != origin && !id.equals(origin.getId())) {
            return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        dishes.setStatus(1);
        if(dishesService.updateById(dishes)){
            dishesService.getById(id);
        }

        return ResponseBean.success(dishes);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/dishes/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
//        dishesService.removeLogicById(id);
        dishesService.removeById(id);
        return ResponseBean.success("success");
    }
}