package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.GuaranteeTask;
import com.yunzhi.inte.service.GuaranteeTaskService;

/**
 * 供给保障;(guarantee_task)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "供给保障对象功能接口")
@RestController
@RequestMapping("/")
public class GuaranteeTaskController extends BaseController {

    @Autowired
    private GuaranteeTaskService guaranteeTaskService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/guaranteeTask/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(guaranteeTaskService.getById(id));
    }

    private Date toDate(String str) throws ParseException {
        String format = "yyyy-MM-dd HH:mm:ss";
        SimpleDateFormat sdf = new SimpleDateFormat(format);
        return sdf.parse(str);
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/guaranteeTask")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("保障序号") @RequestParam(value ="guaranteeNo", required = false) String guaranteeNo,
                             @ApiParam("受领人") @RequestParam(value ="receiver", required = false) String receiver,
                             @ApiParam(value = "开始时间", example = "2022-09-01") @RequestParam(value ="startDate", required = false) String startDate,
                             @ApiParam(value = "结束时间", example = "2022-09-30") @RequestParam(value ="endDate", required = false) String endDate) throws Exception {

        IPage<GuaranteeTask> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<GuaranteeTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(guaranteeNo), "guarantee_no", guaranteeNo);
        queryWrapper.like(!StringUtils.isEmpty(receiver), "receiver", receiver);

        if (!StringUtils.isEmpty(startDate)) {
            Date start = toDate(startDate + " 00:00:00");
            Date end = toDate(endDate + " 23:59:59");
            queryWrapper.le("start_date", end.getTime());
            queryWrapper.ge("end_date", start.getTime());
        }
//        if (!StringUtils.isEmpty(endDate)) {
//            Date end = toDate(endDate + " 23:59:59");
//            queryWrapper.le("end_date", end.getTime());
//        }

        queryWrapper.eq("status", 1);
        queryWrapper.orderByDesc("id");
        IPage<GuaranteeTask> result = guaranteeTaskService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param guaranteeTask 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/guaranteeTask")
    public ResponseBean add(@ApiParam("实例对象") @RequestBody GuaranteeTask guaranteeTask) throws Exception {
        guaranteeTask.setStatus(1);
        guaranteeTask.setCreateDate(new Date());
        guaranteeTaskService.save(guaranteeTask);
        return ResponseBean.success(guaranteeTask);
    }

    /**
     * 更新数据
     *
     * @param guaranteeTask 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/guaranteeTask/{id}")
    public ResponseBean edit(@ApiParam("对象ID") @PathVariable Integer id,
                             @ApiParam("实例对象") @RequestBody GuaranteeTask guaranteeTask) throws Exception {
        guaranteeTask.setId(id);
        guaranteeTaskService.updateById(guaranteeTask);
        return ResponseBean.success(guaranteeTask);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/guaranteeTask/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        guaranteeTaskService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}