package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ExcelUtils;
import com.yunzhi.inte.common.ResponseBean;

import java.util.Date;
import java.util.List;

import com.yunzhi.inte.entity.Store;
import com.yunzhi.inte.service.StoreService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.StoreLog;
import com.yunzhi.inte.service.StoreLogService;

import javax.servlet.http.HttpServletResponse;

/**
 * 库存日志;(store_log)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "库存日志对象功能接口")
@RestController
@RequestMapping("/")
public class StoreLogController extends BaseController {

    @Autowired
    private StoreLogService storeLogService;

    @Autowired
    private StoreService storeService;

//    /**
//     * 通过ID查询单条数据
//     *
//     * @param id 主键
//     * @return 实例对象
//     */
//    @ApiOperation("通过ID查询单条数据")
//    @GetMapping("/storeLog/{id}")
//    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
//        return ResponseBean.success(storeLogService.getById(id));
//    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/storeLog")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("库存ID") @RequestParam(value ="storeId", required = false) Integer storeId,
                             @ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                             @ApiParam("分类ID") @RequestParam(value ="typeId", required = false) Integer typeId) throws Exception {

        IPage<StoreLog> pg = new Page<>(pageNum, pageSize);
        IPage<StoreLog> result = storeLogService.getPageBy(pg, storeId, name, typeId);

        return ResponseBean.success(result);
    }


    /**
     * 导出
     *
     * @param storeId 库存ID
     * @return 查询结果
     */
    @ApiOperation("导出")
    @GetMapping("/storeLog/export")
    public ResponseBean export(@ApiParam("库存ID") @RequestParam(value ="storeId", required = false) Integer storeId,
                               @ApiParam("名称") @RequestParam(value ="name", required = false) String name,
                               @ApiParam("分类ID") @RequestParam(value ="typeId", required = false) Integer typeId,
                               HttpServletResponse response) throws Exception {

        List<StoreLog> result = storeLogService.getListBy(storeId, name, typeId);
        if (null != result && result.size() > 0) {
            for(StoreLog log : result) {
                String optType = "";
                switch (log.getOptType()) {
                    case "in":
                        optType = "入库";
                        break;
                    case "out":
                        optType = "出库";
                        break;
                    case "fix":
                    default:
                        optType = "盘点";
                        break;
                }

                log.setOptType(optType);
            }
        }

        ExcelUtils.flush(response, StoreLog.class, result, "出入库日志");
        return null;
    }

    /**
     * 新增数据
     *
     * @param storeLog 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/storeLog")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody StoreLog storeLog) throws Exception {

        if (storeLog.getStoreId() == null) {
            return ResponseBean.error("未找到对应库存", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        if (null == storeLog.getAmount()) {
            return ResponseBean.error("请设置出入数量", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 因为只有一个人用, 不用考虑并发问题
        Store store = storeService.getById(storeLog.getStoreId());
        Integer preAmount = null == store.getAmount() ? 0 : store.getAmount();
        Integer amount = storeLog.getAmount();
        Integer leftAmount = preAmount;

        // 如果是盘点
        if ("fix".equals(storeLog.getOptType())) {
            if (amount < 0) {
                return ResponseBean.error("盘点库存不能为负", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }

            leftAmount = amount;
        } else {
            if ("out".equals(storeLog.getOptType())) {
                // 如果是出库
                if (amount > 0) {
                    amount = 0 - amount;
                }
            }

            leftAmount = amount + preAmount;

            if (leftAmount < 0) {
                return ResponseBean.error("库存不足", ResponseBean.ERROR_ILLEGAL_PARAMS);
            }
        }

        storeLog.setPreAmount(preAmount);
        storeLog.setAftAmount(leftAmount);
        storeLog.setCreateDate(new Date());
        storeLogService.save(storeLog);

        store.setAmount(leftAmount);
        storeService.updateById(store);

        return ResponseBean.success(storeLog);
    }
//
//    /**
//     * 更新数据
//     *
//     * @param storeLog 实例对象
//     * @return 实例对象
//     */
//    @ApiOperation("更新数据")
//    @PutMapping("/storeLog/{id}")
//    public ResponseBean edit(@ApiParam("对象实体") @RequestBody StoreLog storeLog) throws Exception {
//        storeLogService.updateById(storeLog);
//        return ResponseBean.success(storeLog);
//    }
//
//    /**
//     * 通过主键删除数据
//     *
//     * @param id 主键
//     * @return 是否成功
//     */
//    @ApiOperation("通过主键删除数据")
//    @DeleteMapping("/storeLog/{id}")
//    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
//        storeLogService.removeLogicById(id);
//        return ResponseBean.success("success");
//    }
}