package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.Package;
import com.yunzhi.inte.entity.Store;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.StoreType;
import com.yunzhi.inte.service.StoreTypeService;

/**
 * 库存分类;(store_type)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "库存分类对象功能接口")
@RestController
@RequestMapping("/")
public class StoreTypeController extends BaseController {

    @Autowired
    private StoreTypeService storeTypeService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/storeType/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(storeTypeService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/storeType")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("名称") @RequestParam(value ="name", required = false) String name) throws Exception {

        IPage<StoreType> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<StoreType> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", name);
        queryWrapper.eq("status", 1);
        queryWrapper.orderByDesc("create_date");
        IPage<StoreType> result = storeTypeService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param storeType 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/storeType")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody StoreType storeType) throws Exception {
        StoreType origin = storeTypeService.getExistBy("name", storeType.getName(), false, true);
        if (null != origin) {
            return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        storeType.setStatus(1);
        storeTypeService.save(storeType);
        return ResponseBean.success(storeType);
    }

    /**
     * 更新数据
     *
     * @param id 对象ID
     * @param storeType 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/storeType/{id}")
    public ResponseBean edit(@ApiParam("对象ID") @PathVariable Integer id,
                             @ApiParam("对象实体") @RequestBody StoreType storeType) throws Exception {
        StoreType origin = storeTypeService.getExistBy("name", storeType.getName(), false, true);
        if (null != origin && !id.equals(origin.getId())) {
            return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        storeType.setId(id);
        storeTypeService.updateById(storeType);
        return ResponseBean.success(storeType);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/storeType/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        storeTypeService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}